==> javax.swing-1.0.2.jar: javax/swing/text/html/CSS$Attribute.clj <==
(ns javax.swing.text.html.CSS$Attribute
  "Definitions to be used as a key on AttributeSet's
  that might hold CSS attributes.  Since this is a
  closed set (i.e. defined exactly by the specification),
  it is final and cannot be extended."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.swing.text.html CSS$Attribute]))

(def *-background
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND)

(def *-background-attachment
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_ATTACHMENT)

(def *-background-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_COLOR)

(def *-background-image
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_IMAGE)

(def *-background-position
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_POSITION)

(def *-background-repeat
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_REPEAT)

(def *-border
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER)

(def *-border-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM)

(def *-border-bottom-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_COLOR)

(def *-border-bottom-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_STYLE)

(def *-border-bottom-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_WIDTH)

(def *-border-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_COLOR)

(def *-border-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT)

(def *-border-left-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_COLOR)

(def *-border-left-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_STYLE)

(def *-border-left-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_WIDTH)

(def *-border-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT)

(def *-border-right-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_COLOR)

(def *-border-right-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_STYLE)

(def *-border-right-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_WIDTH)

(def *-border-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_STYLE)

(def *-border-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP)

(def *-border-top-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_COLOR)

(def *-border-top-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_STYLE)

(def *-border-top-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_WIDTH)

(def *-border-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_WIDTH)

(def *-clear
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/CLEAR)

(def *-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/COLOR)

(def *-display
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/DISPLAY)

(def *-float
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FLOAT)

(def *-font
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT)

(def *-font-family
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_FAMILY)

(def *-font-size
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_SIZE)

(def *-font-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_STYLE)

(def *-font-variant
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_VARIANT)

(def *-font-weight
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_WEIGHT)

(def *-height
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/HEIGHT)

(def *-letter-spacing
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LETTER_SPACING)

(def *-line-height
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LINE_HEIGHT)

(def *-list-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE)

(def *-list-style-image
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_IMAGE)

(def *-list-style-position
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_POSITION)

(def *-list-style-type
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_TYPE)

(def *-margin
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN)

(def *-margin-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_BOTTOM)

(def *-margin-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_LEFT)

(def *-margin-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_RIGHT)

(def *-margin-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_TOP)

(def *-padding
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING)

(def *-padding-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_BOTTOM)

(def *-padding-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_LEFT)

(def *-padding-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_RIGHT)

(def *-padding-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_TOP)

(def *-text-align
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_ALIGN)

(def *-text-decoration
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_DECORATION)

(def *-text-indent
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_INDENT)

(def *-text-transform
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_TRANSFORM)

(def *-vertical-align
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/VERTICAL_ALIGN)

(def *-word-spacing
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WORD_SPACING)

(def *-white-space
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WHITE_SPACE)

(def *-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WIDTH)

(defn to-string
  "The string representation of the attribute.  This
   should exactly match the string specified in the
   CSS specification.

  returns: a string representation of the object. - `java.lang.String`"
  ([^javax.swing.text.html.CSS$Attribute this]
    (-> this (.toString))))

(defn get-default-value
  "Fetch the default value for the attribute.
   If there is no default value (such as for
   composite attributes), null will be returned.

  returns: `java.lang.String`"
  ([^javax.swing.text.html.CSS$Attribute this]
    (-> this (.getDefaultValue))))

(defn inherited?
  "Indicates if the attribute should be inherited
   from the parent or not.

  returns: `boolean`"
  ([^javax.swing.text.html.CSS$Attribute this]
    (-> this (.isInherited))))

==> javax.swing-1.0.3.jar: javax/swing/text/html/CSS$Attribute.clj <==
(ns javax.swing.text.html.CSS$Attribute
  "Definitions to be used as a key on AttributeSet's
  that might hold CSS attributes.  Since this is a
  closed set (i.e. defined exactly by the specification),
  it is final and cannot be extended."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.swing.text.html CSS$Attribute]))

(def *-background
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND)

(def *-background-attachment
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_ATTACHMENT)

(def *-background-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_COLOR)

(def *-background-image
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_IMAGE)

(def *-background-position
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_POSITION)

(def *-background-repeat
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BACKGROUND_REPEAT)

(def *-border
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER)

(def *-border-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM)

(def *-border-bottom-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_COLOR)

(def *-border-bottom-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_STYLE)

(def *-border-bottom-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_BOTTOM_WIDTH)

(def *-border-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_COLOR)

(def *-border-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT)

(def *-border-left-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_COLOR)

(def *-border-left-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_STYLE)

(def *-border-left-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_LEFT_WIDTH)

(def *-border-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT)

(def *-border-right-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_COLOR)

(def *-border-right-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_STYLE)

(def *-border-right-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_RIGHT_WIDTH)

(def *-border-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_STYLE)

(def *-border-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP)

(def *-border-top-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_COLOR)

(def *-border-top-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_STYLE)

(def *-border-top-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_TOP_WIDTH)

(def *-border-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/BORDER_WIDTH)

(def *-clear
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/CLEAR)

(def *-color
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/COLOR)

(def *-display
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/DISPLAY)

(def *-float
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FLOAT)

(def *-font
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT)

(def *-font-family
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_FAMILY)

(def *-font-size
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_SIZE)

(def *-font-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_STYLE)

(def *-font-variant
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_VARIANT)

(def *-font-weight
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/FONT_WEIGHT)

(def *-height
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/HEIGHT)

(def *-letter-spacing
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LETTER_SPACING)

(def *-line-height
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LINE_HEIGHT)

(def *-list-style
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE)

(def *-list-style-image
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_IMAGE)

(def *-list-style-position
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_POSITION)

(def *-list-style-type
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/LIST_STYLE_TYPE)

(def *-margin
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN)

(def *-margin-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_BOTTOM)

(def *-margin-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_LEFT)

(def *-margin-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_RIGHT)

(def *-margin-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/MARGIN_TOP)

(def *-padding
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING)

(def *-padding-bottom
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_BOTTOM)

(def *-padding-left
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_LEFT)

(def *-padding-right
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_RIGHT)

(def *-padding-top
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/PADDING_TOP)

(def *-text-align
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_ALIGN)

(def *-text-decoration
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_DECORATION)

(def *-text-indent
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_INDENT)

(def *-text-transform
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/TEXT_TRANSFORM)

(def *-vertical-align
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/VERTICAL_ALIGN)

(def *-word-spacing
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WORD_SPACING)

(def *-white-space
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WHITE_SPACE)

(def *-width
  "Static Constant.

  type: javax.swing.text.html.CSS.Attribute"
  CSS$Attribute/WIDTH)

(defn to-string
  "The string representation of the attribute.  This
   should exactly match the string specified in the
   CSS specification.

  returns: a string representation of the object. - `java.lang.String`"
  (^java.lang.String [^javax.swing.text.html.CSS$Attribute this]
    (-> this (.toString))))

(defn get-default-value
  "Fetch the default value for the attribute.
   If there is no default value (such as for
   composite attributes), null will be returned.

  returns: `java.lang.String`"
  (^java.lang.String [^javax.swing.text.html.CSS$Attribute this]
    (-> this (.getDefaultValue))))

(defn inherited?
  "Indicates if the attribute should be inherited
   from the parent or not.

  returns: `boolean`"
  (^Boolean [^javax.swing.text.html.CSS$Attribute this]
    (-> this (.isInherited))))
